@@ -1,15 +1,20 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
-
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 # all_wildcard.py --- Example of trait attribute wildcard rules
 
-# --[Imports]-------------------------------------------------------------------
-from __future__ import print_function
+# --[Imports]------------------------------------------------------------------
 from traits.api import Any, Str, Int, HasTraits, TraitError
 
 
-# --[Code]----------------------------------------------------------------------
+# --[Code]---------------------------------------------------------------------
 class Person(HasTraits):
 
     # Normal, explicitly defined trait:
@@ -22,7 +27,7 @@ class Person(HasTraits):
     age = Int
 
 
-# --[Example*]------------------------------------------------------------------
+# --[Example*]-----------------------------------------------------------------
 # Create a sample Person:
 bill = Person()
 
