@@ -1,14 +1,20 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 # static_notification.py --- Example of static attribute notification
 
-# --[Imports]-------------------------------------------------------------------
-from __future__ import print_function
+# --[Imports]------------------------------------------------------------------
 from traits.api import HasTraits, Float
 
 
-# --[Code]----------------------------------------------------------------------
+# --[Code]---------------------------------------------------------------------
 class Person(HasTraits):
     weight_kg = Float(0.0)
     height_m = Float(1.0)
@@ -23,7 +29,7 @@ class Person(HasTraits):
         print("The %s trait changed from %s to %s " % (name, old, new))
 
 
-# --[Example*]------------------------------------------------------------------
+# --[Example*]-----------------------------------------------------------------
 bob = Person()
 bob.height_m = 1.75
 # Output: The height_m trait changed from 1.0 to 1.75
