@@ -1,7 +1,14 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
-# --(Delegation Fixes and Improvements)-----------------------------------------
+# --(Delegation Fixes and Improvements)----------------------------------------
 """
 Delegation Fixes and Improvements
 =================================
@@ -90,21 +97,19 @@ notification handler.
 
 """
 
-from __future__ import print_function
-
 # FIXME - this need to be redone without traitsui
 
-from traits.api import *
+from traits.api import Delegate, HasTraits, Instance, Str
 
 
-# --[Parent Class]--------------------------------------------------------------
+# --[Parent Class]-------------------------------------------------------------
 class Parent(HasTraits):
 
     first_name = Str
     last_name = Str
 
 
-# --[Child Class]---------------------------------------------------------------
+# --[Child Class]--------------------------------------------------------------
 class Child(HasTraits):
 
     mother = Instance(Parent)
@@ -114,7 +119,7 @@ class Child(HasTraits):
     last_name = Delegate("father")
 
 
-# --[Example*]------------------------------------------------------------------
+# --[Example*]-----------------------------------------------------------------
 
 mom = Parent(first_name="Julia", last_name="Wilson")
 dad = Parent(first_name="William", last_name="Chase")
