@@ -1,7 +1,14 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
-# --(__getstate__/__setstate__ Changes and Improvements)------------------------
+# --(__getstate__/__setstate__ Changes and Improvements)-----------------------
 """
 __getstate__/__setstate__ Changes and Improvements
 ==================================================
@@ -89,7 +96,7 @@ overriding *__getstate__* using the follow pattern to remove items that should
 not be persisted::
 
     def __getstate__(self):
-        state = super(XXX, self).__getstate__()
+        state = super().__getstate__()
 
         for key in [ 'foo', 'bar' ]:
             if key in state:
@@ -127,14 +134,12 @@ notifications managed by traits are correctly initialized for the object.
 Failure to call this method may result in lost change notifications.
 """
 
-from __future__ import print_function
-from six.moves.cPickle import dumps, loads
+from time import time
 
-from traits.api import *
-from time import time, sleep
+from traits.api import Any, HasTraits, Str
 
 
-# --[Session Class]-------------------------------------------------------------
+# --[Session Class]------------------------------------------------------------
 class Session(HasTraits):
 
     # The name of the session:
@@ -147,7 +152,7 @@ class Session(HasTraits):
         self.created = time()
 
 
-# --[Example*]------------------------------------------------------------------
+# --[Example*]-----------------------------------------------------------------
 
 # The following shows an example of pickling and unpickling a Session object.
 # Unfortunately, it is not possible to successfully pickle objects created as
@@ -163,6 +168,10 @@ print("Session name:", session.name)
 print("Session created:", session.created)
 
 # # Simulate saving the session to a file/database:
+#
+# from pickle import dumps, loads
+# from time import sleep
+#
 # saved_session = dumps(session)
 #
 # # Simulate the passage of time (zzzzZZZZ...):
