@@ -1,7 +1,14 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
-# --(Rewritten Core Traits)-----------------------------------------------------
+# --(Rewritten Core Traits)----------------------------------------------------
 """
 Rewritten Core Traits
 =====================
@@ -19,11 +26,9 @@ are:
 - CComplex
 - CInt
 - CFloat
-- CLong
 - Code
 - Complex
 - CStr
-- CUnicode
 - Dict
 - Directory
 - Enum
@@ -34,7 +39,6 @@ are:
 - Instance
 - Int
 - List
-- Long
 - Password
 - PythonValue
 - Range
@@ -42,7 +46,6 @@ are:
 - Str
 - String
 - Tuple
-- Unicode
 - WeakRef
 
 This may be useful information if you find yourself in need of creating a new
