@@ -1,7 +1,14 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
-# --(Creating New Trait Types)--------------------------------------------------
+# --(Creating New Trait Types)-------------------------------------------------
 """
 Creating New Trait Types
 ========================
@@ -50,7 +57,7 @@ post_setattr(self, object, name, value)
 The subclass can also define a constant default value by setting the class-
 level *default_value* attribute to the desired constant value. For example::
 
-    class OddInt(Int):
+    class OddInt(BaseInt):
 
         default_value = 1
 
@@ -64,7 +71,7 @@ If you have a constant string that can be used as the type's *info* value, you
 can provide it by simple setting the string as the value of the class-level
 *info_text* attribute::
 
-    class OddInt(Int):
+    class OddInt(BaseInt):
 
         info_text = 'an odd integer'
 
@@ -136,12 +143,13 @@ to the preceding section on defining a trait type for additional information
 that applies to properties as well.
 """
 
-# --<Imports>-------------------------------------------------------------------
-from __future__ import print_function
-from traits.api import *
+# --<Imports>------------------------------------------------------------------
+from random import randint
+
+from traits.api import HasTraits, List, TraitError, TraitType
 
 
-# --[DiceRoll Type]-------------------------------------------------------------
+# --[DiceRoll Type]------------------------------------------------------------
 # Define a type whose value represents the roll of a pair of dice:
 class DiceRoll(TraitType):
 
@@ -169,10 +177,7 @@ class DiceRoll(TraitType):
         self.error(object, name, value)
 
 
-# --[RandInt Property]----------------------------------------------------------
-
-from random import randint
-
+# --[RandInt Property]---------------------------------------------------------
 
 # Define a read-only property whose value is a random integer in a specified
 # range:
@@ -180,7 +185,7 @@ class RandInt(TraitType):
 
     # Define the type's constructor:
     def __init__(self, low=1, high=10, **metadata):
-        super(RandInt, self).__init__(**metadata)
+        super().__init__(**metadata)
         self.low = int(low)
         self.high = int(high)
 
@@ -196,7 +201,7 @@ class RandInt(TraitType):
         )
 
 
-# --[Craps Class]---------------------------------------------------------------
+# --[Craps Class]--------------------------------------------------------------
 
 
 # Define a test class containing both new trait types/properties:
@@ -206,7 +211,7 @@ class Craps(HasTraits):
     die = RandInt(1, 6)
 
 
-# --[Example*]------------------------------------------------------------------
+# --[Example*]-----------------------------------------------------------------
 
 # Create a test object:
 craps = Craps()
