@@ -1,7 +1,12 @@
-# Copyright (c) 2008-2019 by Enthought, Inc.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
-
-from __future__ import absolute_import
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 try:
     from traits.version import version as __version__
@@ -11,10 +16,3 @@ except ImportError:
     # hasn't been built, so this isn't a viable Traits installation. OTOH, it
     # can be useful if a simple "import traits" doesn't actually fail.
     __version__ = "unknown"
-
-# Add a NullHandler so 'traits' loggers don't complain when they get used.
-import logging
-
-logging.getLogger(__name__).addHandler(logging.NullHandler())
-
-del logging
