@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   12/06/2005
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Pseudo-package for all of the core symbols from Traits and TraitsUI.
 Use this module for importing Traits names into your namespace. For example::
@@ -21,11 +14,24 @@ Use this module for importing Traits names into your namespace. For example::
     from traits.api import HasTraits
 """
 
-from __future__ import absolute_import
+from .constants import (
+    ComparisonMode,
+    DefaultValue,
+    TraitKind,
+    ValidateTrait,
+    NO_COMPARE,
+    OBJECT_IDENTITY_COMPARE,
+    RICH_COMPARE,
+)
 
 from .trait_base import Uninitialized, Undefined, Missing, Self
+from .trait_converters import as_ctrait
 
-from .trait_errors import TraitError, TraitNotificationError, DelegationError
+from .trait_errors import (
+    TraitError,
+    TraitNotificationError,
+    DelegationError,
+)
 
 from .trait_notifiers import (
     push_exception_handler,
@@ -33,13 +39,11 @@ from .trait_notifiers import (
     TraitChangeNotifyWrapper,
 )
 
-from .category import Category
-
+from .ctrait import CTrait
+from .trait_factory import TraitFactory
 from .traits import (
-    CTrait,
     Trait,
     Property,
-    TraitFactory,
     Default,
     Color,
     RGBColor,
@@ -48,22 +52,17 @@ from .traits import (
 
 from .trait_types import (
     Any,
-    Generic,
     Int,
-    Long,
     Float,
     Complex,
     Str,
     Title,
-    Unicode,
     Bytes,
     Bool,
     CInt,
-    CLong,
     CFloat,
     CComplex,
     CStr,
-    CUnicode,
     CBytes,
     CBool,
     String,
@@ -93,9 +92,12 @@ from .trait_types import (
     Tuple,
     List,
     CList,
+    PrefixList,
     Set,
     CSet,
     Dict,
+    Map,
+    PrefixMap,
     Instance,
     AdaptedTo,
     AdaptsTo,
@@ -103,18 +105,31 @@ from .trait_types import (
     Button,
     ToolbarButton,
     Either,
+    Union,
     Type,
+    Subclass,
     Symbol,
     WeakRef,
     Date,
+    Datetime,
     Time,
-    false,
-    true,
-    undefined,
     Supports,
 )
 
+# Deprecated TraitType subclasses and instances.
+
 from .trait_types import (
+    BaseUnicode,
+    Unicode,
+    BaseCUnicode,
+    CUnicode,
+    BaseLong,
+    Long,
+    BaseCLong,
+    CLong,
+    false,
+    true,
+    undefined,
     ListInt,
     ListFloat,
     ListStr,
@@ -127,27 +142,23 @@ from .trait_types import (
     DictStrAny,
     DictStrStr,
     DictStrInt,
-    DictStrLong,
     DictStrFloat,
     DictStrBool,
     DictStrList,
 )
 
 from .trait_types import (
+    BaseCallable,
     BaseInt,
-    BaseLong,
     BaseFloat,
     BaseComplex,
     BaseStr,
-    BaseUnicode,
     BaseBytes,
     BaseBool,
     BaseCInt,
-    BaseCLong,
     BaseCFloat,
     BaseCComplex,
     BaseCStr,
-    BaseCUnicode,
     BaseCBool,
     BaseFile,
     BaseDirectory,
@@ -160,6 +171,10 @@ from .trait_types import (
 from .trait_types import UUID, ValidatedTuple
 
 from .has_traits import (
+    ABCHasStrictTraits,
+    ABCHasTraits,
+    ABCMetaHasTraits,
+    AbstractViewElement,
     HasTraits,
     HasStrictTraits,
     HasPrivateTraits,
@@ -171,7 +186,7 @@ from .has_traits import (
     MetaHasTraits,
     Vetoable,
     VetoableEvent,
-    traits_super,
+    observe,
     on_trait_change,
     cached_property,
     property_depends_on,
@@ -179,22 +194,13 @@ from .has_traits import (
     isinterface,
 )
 
-try:
-    from .has_traits import ABCHasTraits, ABCHasStrictTraits, ABCMetaHasTraits
-except ImportError:
-    pass
-
+from .base_trait_handler import BaseTraitHandler
+from .trait_handler import TraitHandler
+from .trait_type import TraitType, NoDefaultSpecified
 from .trait_handlers import (
-    BaseTraitHandler,
-    TraitType,
-    TraitHandler,
-    TraitRange,
-    TraitString,
     TraitCoerceType,
     TraitCastType,
     TraitInstance,
-    ThisClass,
-    TraitClass,
     TraitFunction,
     TraitEnum,
     TraitPrefixList,
@@ -202,26 +208,15 @@ from .trait_handlers import (
     TraitPrefixMap,
     TraitCompound,
     TraitList,
-    TraitListObject,
-    TraitListEvent,
-    TraitSetObject,
-    TraitSetEvent,
     TraitDict,
-    TraitDictObject,
-    TraitDictEvent,
     TraitTuple,
-    NO_COMPARE,
-    OBJECT_IDENTITY_COMPARE,
-    RICH_COMPARE,
 )
 
-from .trait_value import (
-    BaseTraitValue,
-    TraitValue,
-    SyncValue,
-    TypeValue,
-    DefaultValue,
-)
+
+from .trait_dict_object import TraitDictEvent, TraitDictObject
+from .trait_list_object import TraitListEvent, TraitListObject
+from .trait_set_object import TraitSetEvent, TraitSetObject
+
 
 from .adaptation.adapter import Adapter
 from .adaptation.adaptation_error import AdaptationError
@@ -232,28 +227,3 @@ from .adaptation.adaptation_manager import (
 )
 
 from .trait_numeric import Array, ArrayOrNone, CArray
-
-try:
-    from . import has_traits as has_traits
-
-    # ---------------------------------------------------------------------------
-    #  Patch the main traits module with the correct definition for the
-    #  ViewElements class:
-    #  NOTE: We do this in a try..except block because traits.ui depends on
-    #  the pyface module (part of the TraitsGUI package) which may not
-    #  necessarily be installed. Not having TraitsGUI means that the 'ui'
-    #  features of traits will not work.
-    # ---------------------------------------------------------------------------
-
-    from traitsui import view_elements
-
-    has_traits.ViewElements = view_elements.ViewElements
-
-    # -------------------------------------------------------------------------------
-    #  Patch the main traits module with the correct definition for the
-    #  ViewElement and ViewSubElement class:
-    # -------------------------------------------------------------------------------
-
-    has_traits.ViewElement = view_elements.ViewElement
-except ImportError:
-    pass
