@@ -1,3 +1,13 @@
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """ Enthought Tool Suite configuration information. """
 
 
@@ -48,13 +58,8 @@ class ETSConfig(object):
     #### operator methods #####################################################
 
     def __init__(self):
-        """
-        Constructor.
-
-        Note that this constructor can only ever be called from within this
-        module, since we don't expose the class.
-
-        """
+        # Note that this constructor can only ever be called from within this
+        # module, since we don't expose the class.
 
         # Shadow attributes for properties.
         self._application_data = None
@@ -64,8 +69,6 @@ class ETSConfig(object):
         self._kiva_backend = None
         self._user_data = None
 
-        return
-
     ###########################################################################
     # 'ETSConfig' interface.
     ###########################################################################
@@ -99,12 +102,14 @@ class ETSConfig(object):
 
         return self._application_data
 
-    def _get_application_data(self):
+    @property
+    def application_data(self):
         """ Property getter, see get_application_data's docstring.
         """
         return self.get_application_data(create=True)
 
-    def _set_application_data(self, application_data):
+    @application_data.setter
+    def application_data(self, application_data):
         """
         Property setter.
 
@@ -112,8 +117,6 @@ class ETSConfig(object):
 
         self._application_data = application_data
 
-        return
-
     def get_application_home(self, create=False):
         """ Return the application home directory path.
 
@@ -157,14 +160,14 @@ class ETSConfig(object):
 
         return self._application_home
 
-    application_data = property(_get_application_data, _set_application_data)
-
-    def _get_application_home(self):
+    @property
+    def application_home(self):
         """ Property getter, see get_application_home's docstring.
         """
         return self.get_application_home(create=True)
 
-    def _set_application_home(self, application_home):
+    @application_home.setter
+    def application_home(self, application_home):
         """
         Property setter.
 
@@ -172,11 +175,8 @@ class ETSConfig(object):
 
         self._application_home = application_home
 
-        return
-
-    application_home = property(_get_application_home, _set_application_home)
-
-    def _get_company(self):
+    @property
+    def company(self):
         """
         Property getter.
 
@@ -187,7 +187,8 @@ class ETSConfig(object):
 
         return self._company
 
-    def _set_company(self, company):
+    @company.setter
+    def company(self, company):
         """
         Property setter for the company name.
 
@@ -195,10 +196,6 @@ class ETSConfig(object):
 
         self._company = company
 
-        return
-
-    company = property(_get_company, _set_company)
-
     @contextmanager
     def provisional_toolkit(self, toolkit):
         """ Perform an operation with toolkit provisionally set
@@ -231,7 +228,8 @@ class ETSConfig(object):
             self._toolkit = ""
             raise
 
-    def _get_toolkit(self):
+    @property
+    def toolkit(self):
         """
         Property getter for the GUI toolkit.  The value returned is, in order
         of preference: the value set by the application; the value specified by
@@ -244,7 +242,8 @@ class ETSConfig(object):
 
         return self._toolkit.split(".")[0]
 
-    def _set_toolkit(self, toolkit):
+    @toolkit.setter
+    def toolkit(self, toolkit):
         """
         Property setter for the GUI toolkit.  The toolkit can be set more than
         once, but only if it is the same one each time.  An application that is
@@ -261,17 +260,15 @@ class ETSConfig(object):
 
         self._toolkit = toolkit
 
-        return
-
-    toolkit = property(_get_toolkit, _set_toolkit)
-
-    def _get_enable_toolkit(self):
+    @property
+    def enable_toolkit(self):
         """
         Deprecated: This property is no longer used.
 
-        Property getter for the Enable backend.  The value returned is, in order
-        of preference: the value set by the application; the value specified by
-        the 'ENABLE_TOOLKIT' environment variable; otherwise the empty string.
+        Property getter for the Enable backend.  The value returned is, in
+        order of preference: the value set by the application; the value
+        specified by the 'ENABLE_TOOLKIT' environment variable; otherwise the
+        empty string.
         """
         from warnings import warn
 
@@ -279,34 +276,34 @@ class ETSConfig(object):
 
         return self.toolkit
 
-    def _set_enable_toolkit(self, toolkit):
+    @enable_toolkit.setter
+    def enable_toolkit(self, toolkit):
         """
         Deprecated.
 
-        Property setter for the Enable toolkit.  The toolkit can be set more than
-        once, but only if it is the same one each time.  An application that is
-        written for a particular toolkit can explicitly set it before any other
-        module that gets the value is imported.
+        Property setter for the Enable toolkit.  The toolkit can be set more
+        than once, but only if it is the same one each time.  An application
+        that is written for a particular toolkit can explicitly set it before
+        any other module that gets the value is imported.
         """
         from warnings import warn
 
         warn("Use of the enable_toolkit attribute is deprecated.")
 
-        return
-
-    enable_toolkit = property(_get_enable_toolkit, _set_enable_toolkit)
-
-    def _get_kiva_backend(self):
+    @property
+    def kiva_backend(self):
         """
         Property getter for the Kiva backend. The value returned is dependent
-        on the value of the toolkit property. If toolkit specifies a kiva backend
-        using the extended syntax: <enable toolkit>[.<kiva backend>] then the
-        value of the property will be whatever was specified. Otherwise the
-        value will be a reasonable default for the given enable backend.
+        on the value of the toolkit property. If toolkit specifies a kiva
+        backend using the extended syntax: <enable toolkit>[.<kiva backend>]
+        then the value of the property will be whatever was specified.
+        Otherwise the value will be a reasonable default for the given enable
+        backend.
         """
         if self._toolkit is None:
             raise AttributeError(
-                "The kiva_backend attribute is dependent on toolkit, which has not been set."
+                "The kiva_backend attribute is dependent on toolkit, "
+                "which has not been set."
             )
 
         if self._kiva_backend is None:
@@ -318,18 +315,15 @@ class ETSConfig(object):
                     self._kiva_backend = (
                         "quartz" if sys.platform == "darwin" else "image"
                     )
-                elif self.toolkit == "qt4":
+                elif self.toolkit in ["qt4", "qt"]:
                     self._kiva_backend = "image"
-                elif self.toolkit == "pyglet":
-                    self._kiva_backend = "gl"
                 else:
                     self._kiva_backend = "image"
 
         return self._kiva_backend
 
-    kiva_backend = property(_get_kiva_backend)
-
-    def _get_user_data(self):
+    @property
+    def user_data(self):
         """
         Property getter.
 
@@ -345,7 +339,8 @@ class ETSConfig(object):
 
         return self._user_data
 
-    def _set_user_data(self, user_data):
+    @user_data.setter
+    def user_data(self, user_data):
         """
         Property setter.
 
@@ -353,10 +348,6 @@ class ETSConfig(object):
 
         self._user_data = user_data
 
-        return
-
-    user_data = property(_get_user_data, _set_user_data)
-
     #### private methods #####################################################
 
     # fixme: In future, these methods could allow the properties to be set
@@ -416,7 +407,8 @@ class ETSConfig(object):
             if user is not None:
                 directory_name += "_%s" % user
             warn(
-                'Environment variable "%s" not set, setting home directory to %s'
+                'Environment variable "%s" not set, '
+                'setting home directory to %s'
                 % (environment_variable, parent_directory)
             )
 
@@ -481,9 +473,10 @@ class ETSConfig(object):
                 # naive way...
 
                 # Check if the usr_dir is C:\\John Doe\\Documents and Settings.
-                # If yes, then we should modify the usr_dir to be 'My Documents'.
-                # If no, then the user must have modified the os.environ
-                # variables and the directory chosen is a desirable one.
+                # If yes, then we should modify the usr_dir to be
+                # 'My Documents'. If no, then the user must have modified the
+                # os.environ variables and the directory chosen is a desirable
+                # one.
                 desired_dir = os.path.join(parent_directory, "My Documents")
 
                 if os.path.exists(desired_dir):
