@@ -1,3 +1,13 @@
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """ Tools for having doctest and unittest work together more nicely.
 
     Eclipse's PyDev plugin will run your unittest files for you very nicely.
@@ -7,8 +17,8 @@
 
 # Standard library imports
 import doctest
-from traits.testing.unittest_tools import unittest
-import sys
+import unittest
+
 
 def doctest_for_module(module):
     """ Create a TestCase from a module's doctests that will be run by the
@@ -43,13 +53,16 @@ def doctest_for_module(module):
     """
 
     class C(unittest.TestCase):
-        def test_dummy(self): pass # Make the test case loader find us
+        def test_dummy(self):
+            pass  # Make the test case loader find us
+
         def run(self, result=None):
             # doctest doesn't like nose.result.TextTestResult objects,
             # so we try to determine if thats what we're dealing
             # with and use its internal result attribute instead
-            if hasattr(result, 'result'):
+            if hasattr(result, "result"):
                 doctest.DocTestSuite(module).run(result.result)
             else:
                 doctest.DocTestSuite(module).run(result)
+
     return C
