@@ -1,16 +1,12 @@
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in /LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: David C. Morrill
-# Description: <Traits component>
-
-from __future__ import absolute_import
+# Thanks for using Enthought open source!
 
 import unittest
 
@@ -109,8 +105,6 @@ class CloneTestCase(unittest.TestCase):
         bc = b.clone_traits(traits="all", copy="deep")
         self.assertNotEqual(id(bc.x), id(f), "Foo x not cloned")
 
-        return
-
     def test_instance(self):
         b = ClassWithInstance()
 
@@ -122,8 +116,6 @@ class CloneTestCase(unittest.TestCase):
         bc = b.clone_traits(traits="all", copy="deep")
         self.assertNotEqual(id(bc.x), id(f), "Foo x not cloned")
 
-        return
-
     def test_class_attribute_missing(self):
         """ This test demonstrates a problem with Traits objects with class
         attributes.  A change to the value of a class attribute via one
@@ -151,8 +143,6 @@ class CloneTestCase(unittest.TestCase):
         # object has no attribute 'name'
         self.assertEqual(s, c.name)
 
-        return
-
     def test_Any_circular_references(self):
 
         # Demonstrates that Any traits default to copy='ref'
