@@ -1,12 +1,12 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  All rights reserved.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in /LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-
-from __future__ import absolute_import
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 import unittest
 
@@ -41,7 +41,7 @@ class CopyTraitsBase(unittest.TestCase):
     __test__ = False
 
     def setUp(self):
-        super(CopyTraitsBase, self).setUp()
+        super().setUp()
         self.shared = Shared(s="shared")
         self.foo = Foo(shared=self.shared, s="foo")
         self.bar = Bar(shared=self.shared, foo=self.foo, s="bar")
@@ -52,8 +52,6 @@ class CopyTraitsBase(unittest.TestCase):
         self.bar2 = Bar(shared=self.shared2, foo=self.foo2, s="bar2")
         self.baz2 = Baz(shared=self.shared2, bar=self.bar2, s="baz2")
 
-        return
-
     def set_shared_copy(self, value):
         """ Change the copy style for the 'shared' traits. """
         self.foo.base_trait("shared").copy = value
@@ -65,7 +63,7 @@ class TestCopyTraitsSetup(CopyTraitsBase):
     __test__ = True
 
     def setUp(self):
-        super(TestCopyTraitsSetup, self).setUp()
+        super().setUp()
 
     def test_setup(self):
         self.assertIs(self.foo, self.bar.foo)
@@ -167,11 +165,8 @@ class TestCopyTraitsSharedCopyNone(CopyTraits, CopyTraitsSharedCopyNone):
     __test__ = False
 
     def setUp(self):
-        # super(TestCopyTraitsSharedCopyNone,self).setUp()
-
         # deep is the default value for Instance trait copy
         self.set_shared_copy("deep")
-        return
 
 
 class TestCopyTraitsCopyNotSpecified(
@@ -180,33 +175,27 @@ class TestCopyTraitsCopyNotSpecified(
     __test__ = True
 
     def setUp(self):
-        #        super(TestCopyTraitsCopyNotSpecified,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyNone.setUp(self)
         self.baz2.copy_traits(self.baz)
-        return
 
 
 class TestCopyTraitsCopyShallow(CopyTraitsBase, TestCopyTraitsSharedCopyNone):
     __test__ = True
 
     def setUp(self):
-        #        super(TestCopyTraitsCopyShallow,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyNone.setUp(self)
         self.baz2.copy_traits(self.baz, copy="shallow")
-        return
 
 
 class TestCopyTraitsCopyDeep(CopyTraitsBase, TestCopyTraitsSharedCopyNone):
     __test__ = True
 
     def setUp(self):
-        #        super(TestCopyTraitsCopyDeep,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyNone.setUp(self)
         self.baz2.copy_traits(self.baz, copy="deep")
-        return
 
 
 class CopyTraitsSharedCopyRef(object):
@@ -239,9 +228,7 @@ class TestCopyTraitsSharedCopyRef(CopyTraits, CopyTraitsSharedCopyRef):
     __test__ = False
 
     def setUp(self):
-        # super(TestCopyTraitsSharedCopyRef,self).setUp()
         self.set_shared_copy("ref")
-        return
 
 
 # The next three tests demonstrate that a 'ref' trait is always copied as a
@@ -256,7 +243,6 @@ class TestCopyTraitsCopyNotSpecifiedSharedRef(
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyRef.setUp(self)
         self.baz2.copy_traits(self.baz)
-        return
 
 
 class TestCopyTraitsCopyShallowSharedRef(
@@ -268,7 +254,6 @@ class TestCopyTraitsCopyShallowSharedRef(
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyRef.setUp(self)
         self.baz2.copy_traits(self.baz, copy="shallow")
-        return
 
 
 class TestCopyTraitsCopyDeepSharedRef(
@@ -280,4 +265,3 @@ class TestCopyTraitsCopyDeepSharedRef(
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyRef.setUp(self)
         self.baz2.copy_traits(self.baz, copy="deep")
-        return
