@@ -1,3 +1,13 @@
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """ Tests for the extended notifiers.
 
 The "extended notifiers" are set up internally when using extended traits, to
@@ -8,8 +18,6 @@ listeners to `a:b` when `a` changes.
 """
 import unittest
 
-import six
-
 from traits import trait_notifiers
 from traits.api import Float, HasTraits, List
 
@@ -40,7 +48,7 @@ class ExtendedNotifiers(HasTraits):
         for listener in fail_listeners:
             self._on_trait_change(listener, "fail", dispatch="extended")
 
-        super(ExtendedNotifiers, self).__init__(**traits)
+        super().__init__(**traits)
 
     ok = Float
     fail = Float
@@ -199,10 +207,16 @@ class TestExtendedNotifiers(unittest.TestCase):
         obj = ExtendedNotifiers()
         obj.fail = 1
 
-        six.assertCountEqual(self, [0, 1, 2, 3, 4], obj.exceptions_from)
+        self.assertCountEqual([0, 1, 2, 3, 4], obj.exceptions_from)
         self.assertEqual([(obj, "fail", 0, 1)] * 5, self.exceptions)
 
     def test_extended_notifiers_functions(self):
+        calls_0.clear()
+        calls_1.clear()
+        calls_2.clear()
+        calls_3.clear()
+        calls_4.clear()
+
         obj = ExtendedNotifiers()
 
         obj._on_trait_change(function_listener_0, "ok", dispatch="extended")
@@ -214,6 +228,9 @@ class TestExtendedNotifiers(unittest.TestCase):
         obj.ok = 2
         obj.ok = 3
 
+        expected_0 = [True, True]
+        self.assertEqual(expected_0, calls_0)
+
         expected_1 = [2, 3]
         self.assertEqual(expected_1, calls_1)
 
@@ -229,6 +246,8 @@ class TestExtendedNotifiers(unittest.TestCase):
     def test_extended_notifiers_functions_failing(self):
         obj = ExtendedNotifiers()
 
+        exceptions_from.clear()
+
         obj._on_trait_change(
             failing_function_listener_0, "fail", dispatch="extended"
         )
@@ -247,7 +266,7 @@ class TestExtendedNotifiers(unittest.TestCase):
 
         obj.fail = 1
 
-        six.assertCountEqual(self, [0, 1, 2, 3, 4], obj.exceptions_from)
+        self.assertCountEqual([0, 1, 2, 3, 4], obj.exceptions_from)
         # 10 failures: 5 are from the internal extended listeners, see
         # test_extended_notifiers_methods_failing
         self.assertEqual([(obj, "fail", 0, 1)] * 10, self.exceptions)
