@@ -1,29 +1,21 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2007, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in /LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-# ------------------------------------------------------------------------------
-
-from __future__ import absolute_import
+# Thanks for using Enthought open source!
 
 import unittest
 
 from traits.api import (
-    Float,
     HasTraits,
     Int,
-    ReadOnly,
+    List,
     Str,
     TraitError,
-    Undefined,
 )
 
 
@@ -81,6 +73,40 @@ class GetTraitTestCase(unittest.TestCase):
 
     def test_dir(self):
         b = FooBar()
-        self.assertIn("baz", dir(b))
-        self.assertIn("num", dir(b))
-        self.assertIn("edit_traits", dir(b))
+        names = dir(b)
+        self.assertIn("baz", names)
+        self.assertIn("num", names)
+        self.assertIn("edit_traits", names)
+
+        # Issue 925: _notifiers not shown in dir()
+        self.assertIn("_notifiers", names)
+
+        # Ensure no duplicates
+        self.assertEqual(len(set(names)), len(names))
+
+    def test_trait_name_with_list_items(self):
+        # Dynamically added a List trait causes an "_items" to be added, but
+        # that should not be reported by HasTraits.traits
+
+        class Base(HasTraits):
+            pass
+
+        a = Base()
+        # This adds an instance trait for "pins_items" as well.
+        a.add_trait("pins", List())
+
+        self.assertIn("pins", a.traits())
+        self.assertNotIn("pins_items", a.traits())
+
+    def test_trait_name_with_items(self):
+        # Dynamically added traits with name "*_items" is also skipped.
+
+        class Base(HasTraits):
+            pass
+
+        a = Base()
+        a.add_trait("good_items", Str())
+
+        # If enthought/traits#1329 is fixed, then the following assertion
+        # should fail.
+        self.assertNotIn("good_items", a.traits())
