@@ -1,23 +1,17 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2013, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in /LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#------------------------------------------------------------------------------
-
-from __future__ import absolute_import
+# Thanks for using Enthought open source!
 
 import unittest
 
-from ..trait_types import Int
-from ..has_traits import HasTraits
+from traits.trait_types import Int
+from traits.has_traits import HasTraits
 
 
 class Foo(HasTraits):
@@ -43,13 +37,11 @@ class TestTraitDefaultInitializer(unittest.TestCase):
 
     def test_reset_to_default(self):
         foo = Foo(bar=3)
-        foo.reset_traits(traits=['bar'])
+        foo.reset_traits(traits=["bar"])
         self.assertEqual(foo.bar, 4)
 
     def test_error_propagation_in_default_methods(self):
-
         class FooException(Foo):
-
             def _bar_default(self):
                 1 / 0
 
@@ -57,7 +49,6 @@ class TestTraitDefaultInitializer(unittest.TestCase):
         self.assertRaises(ZeroDivisionError, lambda: foo.bar)
 
         class FooKeyError(Foo):
-
             def _bar_default(self):
                 raise KeyError()
 
