@@ -1,23 +1,17 @@
-# ------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: David C. Morrill Date: 03/20/2003 Description: Unit Test Case for the
-# Traits Package
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 #  Imports
-from __future__ import absolute_import, print_function
 
 import unittest
-
-import six
+import warnings
 
 from traits.api import (
     Any,
@@ -25,14 +19,17 @@ from traits.api import (
     CBytes,
     CFloat,
     CInt,
-    CLong,
+    ComparisonMode,
+    Color,
     Delegate,
     Float,
+    Font,
     HasTraits,
     Instance,
     Int,
     List,
-    Long,
+    Range,
+    RGBColor,
     Str,
     This,
     Trait,
@@ -40,19 +37,14 @@ from traits.api import (
     TraitList,
     TraitPrefixList,
     TraitPrefixMap,
-    TraitRange,
     Tuple,
     pop_exception_handler,
     push_exception_handler,
 )
+from traits.testing.optional_dependencies import requires_traitsui
 
 #  Base unit test classes:
 
-if six.PY2:
-    LONG_TYPE = long
-else:
-    LONG_TYPE = int
-
 
 class BaseTest(object):
     def assign(self, value):
@@ -104,41 +96,27 @@ class test_base2(unittest.TestCase):
         mapped_values=None,
     ):
         obj = self.obj
-        try:
-            # Make sure the default value is correct:
-            msg = "default value"
-            value = default_value
-            self.assertEqual(getattr(obj, name), value)
 
-            # Iterate over all legal values being tested:
-            if actual_values is None:
-                actual_values = good_values
-            msg = "legal values"
-            i = 0
-            for value in good_values:
-                setattr(obj, name, value)
-                self.assertEqual(getattr(obj, name), actual_values[i])
-                if mapped_values is not None:
-                    self.assertEqual(
-                        getattr(obj, name + "_"), mapped_values[i]
-                    )
-                i += 1
+        # Make sure the default value is correct:
+        value = default_value
+        self.assertEqual(getattr(obj, name), value)
 
-            # Iterate over all illegal values being tested:
-            msg = "illegal values"
-            for value in bad_values:
-                self.assertRaises(TraitError, setattr, obj, name, value)
-        except:
-            print(
-                "Failed while testing %s for value: %s(%s) in %s"
-                % (
-                    msg,
-                    value,
-                    value.__class__.__name__,
-                    self.__class__.__name__,
+        # Iterate over all legal values being tested:
+        if actual_values is None:
+            actual_values = good_values
+        i = 0
+        for value in good_values:
+            setattr(obj, name, value)
+            self.assertEqual(getattr(obj, name), actual_values[i])
+            if mapped_values is not None:
+                self.assertEqual(
+                    getattr(obj, name + "_"), mapped_values[i]
                 )
-            )
-            raise
+            i += 1
+
+        # Iterate over all illegal values being tested:
+        for value in bad_values:
+            self.assertRaises(TraitError, setattr, obj, name, value)
 
 
 class AnyTrait(HasTraits):
@@ -147,10 +125,11 @@ class AnyTrait(HasTraits):
 
 class AnyTraitTest(BaseTest, unittest.TestCase):
 
-    obj = AnyTrait()
+    def setUp(self):
+        self.obj = AnyTrait()
 
     _default_value = None
-    _good_values = [10.0, "ten", u"ten", [10], {"ten": 10}, (10,), None, 1j]
+    _good_values = [10.0, b"ten", "ten", [10], {"ten": 10}, (10,), None, 1j]
     _mapped_values = []
     _bad_values = []
 
@@ -165,32 +144,31 @@ class IntTrait(HasTraits):
 
 class CoercibleIntTest(AnyTraitTest):
 
-    obj = CoercibleIntTrait()
+    def setUp(self):
+        self.obj = CoercibleIntTrait()
 
     _default_value = 99
     _good_values = [
         10,
         -10,
-        LONG_TYPE(10),
-        LONG_TYPE(-10),
         10.1,
         -10.1,
         "10",
         "-10",
-        u"10",
-        u"-10",
+        b"10",
+        b"-10",
     ]
     _bad_values = [
         "10L",
         "-10L",
         "10.1",
         "-10.1",
-        u"10L",
-        u"-10L",
-        u"10.1",
-        u"-10.1",
+        b"10L",
+        b"-10L",
+        b"10.1",
+        b"-10.1",
         "ten",
-        u"ten",
+        b"ten",
         [10],
         {"ten": 10},
         (10,),
@@ -202,21 +180,19 @@ class CoercibleIntTest(AnyTraitTest):
         try:
             return int(value)
         except:
-            try:
-                return int(float(value))
-            except:
-                return int(LONG_TYPE(value))
+            return int(float(value))
 
 
 class IntTest(AnyTraitTest):
 
-    obj = IntTrait()
+    def setUp(self):
+        self.obj = IntTrait()
 
     _default_value = 99
-    _good_values = [10, -10, LONG_TYPE(10), LONG_TYPE(-10)]
+    _good_values = [10, -10]
     _bad_values = [
         "ten",
-        u"ten",
+        b"ten",
         [10],
         {"ten": 10},
         (10,),
@@ -228,14 +204,14 @@ class IntTest(AnyTraitTest):
         "-10L",
         "10.1",
         "-10.1",
-        u"10L",
-        u"-10L",
-        u"10.1",
-        u"-10.1",
+        b"10L",
+        b"-10L",
+        b"10.1",
+        b"-10.1",
         "10",
         "-10",
-        u"10",
-        u"-10",
+        b"10",
+        b"-10",
     ]
 
     try:
@@ -258,99 +234,7 @@ class IntTest(AnyTraitTest):
         try:
             return int(value)
         except:
-            try:
-                return int(float(value))
-            except:
-                return int(LONG_TYPE(value))
-
-
-class CoercibleLongTrait(HasTraits):
-    value = CLong(LONG_TYPE(99))
-
-
-class LongTrait(HasTraits):
-    value = Long(LONG_TYPE(99))
-
-
-class CoercibleLongTest(AnyTraitTest):
-
-    obj = CoercibleLongTrait()
-
-    _default_value = LONG_TYPE(99)
-    _good_values = [
-        10,
-        -10,
-        LONG_TYPE(10),
-        LONG_TYPE(-10),
-        10.1,
-        -10.1,
-        "10",
-        "-10",
-        u"10",
-        u"-10",
-    ]
-    if six.PY2:
-        _good_values.extend(["10L", "-10L", u"10L", u"-10L"])
-    _bad_values = [
-        "10.1",
-        "-10.1",
-        u"10.1",
-        u"-10.1",
-        "ten",
-        u"ten",
-        [10],
-        [LONG_TYPE(10)],
-        {"ten": 10},
-        (10,),
-        (LONG_TYPE(10),),
-        None,
-        1j,
-    ]
-
-    def coerce(self, value):
-        try:
-            return LONG_TYPE(value)
-        except:
-            return LONG_TYPE(float(value))
-
-
-class LongTest(AnyTraitTest):
-
-    obj = LongTrait()
-
-    _default_value = LONG_TYPE(99)
-    _good_values = [10, -10, LONG_TYPE(10), LONG_TYPE(-10)]
-    _bad_values = [
-        "ten",
-        u"ten",
-        [10],
-        [LONG_TYPE(10)],
-        {"ten": 10},
-        (10,),
-        (LONG_TYPE(10),),
-        None,
-        1j,
-        10.1,
-        -10.1,
-        "10",
-        "-10",
-        "10L",
-        "-10L",
-        "10.1",
-        "-10.1",
-        u"10",
-        u"-10",
-        u"10L",
-        u"-10L",
-        u"10.1",
-        u"-10.1",
-    ]
-
-    def coerce(self, value):
-        try:
-            return LONG_TYPE(value)
-        except:
-            return LONG_TYPE(float(value))
+            return int(float(value))
 
 
 class CoercibleFloatTrait(HasTraits):
@@ -362,32 +246,31 @@ class FloatTrait(HasTraits):
 
 
 class CoercibleFloatTest(AnyTraitTest):
-    obj = CoercibleFloatTrait()
+    def setUp(self):
+        self.obj = CoercibleFloatTrait()
 
     _default_value = 99.0
     _good_values = [
         10,
         -10,
-        LONG_TYPE(10),
-        LONG_TYPE(-10),
         10.1,
         -10.1,
         "10",
         "-10",
         "10.1",
         "-10.1",
-        u"10",
-        u"-10",
-        u"10.1",
-        u"-10.1",
+        b"10",
+        b"-10",
+        b"10.1",
+        b"-10.1",
     ]
     _bad_values = [
         "10L",
         "-10L",
-        u"10L",
-        u"-10L",
+        b"10L",
+        b"-10L",
         "ten",
-        u"ten",
+        b"ten",
         [10],
         {"ten": 10},
         (10,),
@@ -396,20 +279,18 @@ class CoercibleFloatTest(AnyTraitTest):
     ]
 
     def coerce(self, value):
-        try:
-            return float(value)
-        except:
-            return float(LONG_TYPE(value))
+        return float(value)
 
 
 class FloatTest(AnyTraitTest):
-    obj = FloatTrait()
+    def setUp(self):
+        self.obj = FloatTrait()
 
     _default_value = 99.0
     _good_values = [10, -10, 10.1, -10.1]
     _bad_values = [
         "ten",
-        u"ten",
+        b"ten",
         [10],
         {"ten": 10},
         (10,),
@@ -421,22 +302,16 @@ class FloatTest(AnyTraitTest):
         "-10L",
         "10.1",
         "-10.1",
-        u"10",
-        u"-10",
-        u"10L",
-        u"-10L",
-        u"10.1",
-        u"-10.1",
+        b"10",
+        b"-10",
+        b"10L",
+        b"-10L",
+        b"10.1",
+        b"-10.1",
     ]
 
-    if six.PY2:
-        _good_values.extend([LONG_TYPE(-10), LONG_TYPE(10)])
-
     def coerce(self, value):
-        try:
-            return float(value)
-        except:
-            return float(LONG_TYPE(value))
+        return float(value)
 
 
 #  Trait that can only have 'complex'(i.e. imaginary) values:
@@ -447,15 +322,13 @@ class ImaginaryValueTrait(HasTraits):
 
 
 class ImaginaryValueTest(AnyTraitTest):
-
-    obj = ImaginaryValueTrait()
+    def setUp(self):
+        self.obj = ImaginaryValueTrait()
 
     _default_value = 99.0 - 99.0j
     _good_values = [
         10,
         -10,
-        LONG_TYPE(10),
-        LONG_TYPE(-10),
         10.1,
         -10.1,
         "10",
@@ -472,13 +345,10 @@ class ImaginaryValueTest(AnyTraitTest):
         "10+10j",
         "10-10j",
     ]
-    _bad_values = [u"10L", u"-10L", "ten", [10], {"ten": 10}, (10,), None]
+    _bad_values = [b"10L", "-10L", "ten", [10], {"ten": 10}, (10,), None]
 
     def coerce(self, value):
-        try:
-            return complex(value)
-        except:
-            return complex(LONG_TYPE(value))
+        return complex(value)
 
 
 class StringTrait(HasTraits):
@@ -487,14 +357,13 @@ class StringTrait(HasTraits):
 
 class StringTest(AnyTraitTest):
 
-    obj = StringTrait()
+    def setUp(self):
+        self.obj = StringTrait()
 
     _default_value = "string"
     _good_values = [
         10,
         -10,
-        LONG_TYPE(10),
-        LONG_TYPE(-10),
         10.1,
         -10.1,
         "10",
@@ -504,7 +373,6 @@ class StringTest(AnyTraitTest):
         "10.1",
         "-10.1",
         "string",
-        u"string",
         1j,
         [10],
         ["ten"],
@@ -518,68 +386,21 @@ class StringTest(AnyTraitTest):
         return str(value)
 
 
-class UnicodeTrait(HasTraits):
-    value = Trait(u"unicode")
-
-
-class UnicodeTest(StringTest):
-
-    obj = UnicodeTrait()
-
-    _default_value = u"unicode"
-    _good_values = [
-        10,
-        -10,
-        LONG_TYPE(10),
-        LONG_TYPE(-10),
-        10.1,
-        -10.1,
-        "10",
-        "-10",
-        "10L",
-        "-10L",
-        "10.1",
-        "-10.1",
-        "",
-        u"",
-        "string",
-        u"string",
-        1j,
-        [10],
-        ["ten"],
-        [u"ten"],
-        {"ten": 10},
-        (10,),
-        None,
-    ]
-    _bad_values = []
-
-    def coerce(self, value):
-        return str(value)
-
-
 class BytesTrait(HasTraits):
     value = Bytes(b"bytes")
 
 
-version_dependent = ["", "string"]
-
-
 class BytesTest(StringTest):
 
-    obj = BytesTrait()
+    def setUp(self):
+        self.obj = BytesTrait()
 
     _default_value = b"bytes"
-    _good_values = [b"", b"10", b"-10"] + (
-        version_dependent if six.PY2 else []
-    )
+    _good_values = [b"", b"10", b"-10"]
     _bad_values = [
         10,
         -10,
-        LONG_TYPE(10),
         10.1,
-        u"unicode",
-        u"",
         [b""],
         [b"bytes"],
         [0],
@@ -587,7 +408,9 @@ class BytesTest(StringTest):
         (b"",),
         None,
         True,
-    ] + ([] if six.PY2 else version_dependent)
+        "",
+        "string",
+    ]
 
     def coerce(self, value):
         return bytes(value)
@@ -597,32 +420,10 @@ class CoercibleBytesTrait(HasTraits):
     value = CBytes(b"bytes")
 
 
-version_dependent = [
-    "",
-    "string",
-    u"unicode",
-    u"",
-    -10,
-    10.1,
-    [b""],
-    [b"bytes"],
-    [-10],
-    (-10,),
-    {-10: "foo"},
-    set([-10]),
-    [256],
-    (256,),
-    {256: "foo"},
-    set([256]),
-    {b"ten": b"10"},
-    (b"",),
-    None,
-]
-
-
 class CoercibleBytesTest(StringTest):
 
-    obj = CoercibleBytesTrait()
+    def setUp(self):
+        self.obj = CoercibleBytesTrait()
 
     _default_value = b"bytes"
     _good_values = [
@@ -630,29 +431,47 @@ class CoercibleBytesTest(StringTest):
         b"10",
         b"-10",
         10,
-        LONG_TYPE(10),
         [10],
         (10,),
         set([10]),
         {10: "foo"},
         True,
-    ] + (version_dependent if six.PY2 else [])
-    _bad_values = [] if six.PY2 else version_dependent
+    ]
+    _bad_values = [
+        "",
+        "string",
+        -10,
+        10.1,
+        [b""],
+        [b"bytes"],
+        [-10],
+        (-10,),
+        {-10: "foo"},
+        set([-10]),
+        [256],
+        (256,),
+        {256: "foo"},
+        set([256]),
+        {b"ten": b"10"},
+        (b"",),
+        None,
+    ]
 
     def coerce(self, value):
         return bytes(value)
 
 
 class EnumTrait(HasTraits):
-    value = Trait([1, "one", 2, "two", 3, "three", 4.4, u"four.four"])
+    value = Trait([1, "one", 2, "two", 3, "three", 4.4, "four.four"])
 
 
 class EnumTest(AnyTraitTest):
 
-    obj = EnumTrait()
+    def setUp(self):
+        self.obj = EnumTrait()
 
     _default_value = 1
-    _good_values = [1, "one", 2, "two", 3, "three", 4.4, u"four.four"]
+    _good_values = [1, "one", 2, "two", 3, "three", 4.4, "four.four"]
     _bad_values = [0, "zero", 4, None]
 
 
@@ -661,7 +480,8 @@ class MappedTrait(HasTraits):
 
 
 class MappedTest(AnyTraitTest):
-    obj = MappedTrait()
+    def setUp(self):
+        self.obj = MappedTrait()
 
     _default_value = "one"
     _good_values = ["one", "two", "three"]
@@ -669,12 +489,17 @@ class MappedTest(AnyTraitTest):
     _bad_values = ["four", 1, 2, 3, [1], (1,), {1: 1}, None]
 
 
-class PrefixListTrait(HasTraits):
-    value = Trait("one", TraitPrefixList("one", "two", "three"))
+# Suppress DeprecationWarning from TraitPrefixList instantiation.
+with warnings.catch_warnings():
+    warnings.filterwarnings(action="ignore", category=DeprecationWarning)
+
+    class PrefixListTrait(HasTraits):
+        value = Trait("one", TraitPrefixList("one", "two", "three"))
 
 
 class PrefixListTest(AnyTraitTest):
-    obj = PrefixListTrait()
+    def setUp(self):
+        self.obj = PrefixListTrait()
 
     _default_value = "one"
     _good_values = [
@@ -694,12 +519,17 @@ class PrefixListTest(AnyTraitTest):
         return {"o": "one", "on": "one", "tw": "two", "th": "three"}[value[:2]]
 
 
-class PrefixMapTrait(HasTraits):
-    value = Trait("one", TraitPrefixMap({"one": 1, "two": 2, "three": 3}))
+# Suppress DeprecationWarning from TraitPrefixMap instantiation.
+with warnings.catch_warnings():
+    warnings.filterwarnings(action="ignore", category=DeprecationWarning)
+
+    class PrefixMapTrait(HasTraits):
+        value = Trait("one", TraitPrefixMap({"one": 1, "two": 2, "three": 3}))
 
 
 class PrefixMapTest(AnyTraitTest):
-    obj = PrefixMapTrait()
+    def setUp(self):
+        self.obj = PrefixMapTrait()
 
     _default_value = "one"
     _good_values = [
@@ -720,58 +550,64 @@ class PrefixMapTest(AnyTraitTest):
         return {"o": "one", "on": "one", "tw": "two", "th": "three"}[value[:2]]
 
 
-class IntRangeTrait(HasTraits):
-    value = Trait(3, TraitRange(2, 5))
+# This test a combination of Trait, a default, a mapping and a function
+
+def str_cast_to_int(object, name, value):
+    """ A function that validates the value is a str and then converts
+    it to an int using its length.
+    """
+    if not isinstance(value, str):
+        raise TraitError("Not a string!")
+    return len(value)
 
 
-class IntRangeTest(AnyTraitTest):
+class TraitWithMappingAndCallable(HasTraits):
 
-    obj = IntRangeTrait()
-
-    _default_value = 3
-    _good_values = [2, 3, 4, 5]
-    _bad_values = [0, 1, 6, 0.999, 6.01, "two", "0.999", "6.01", None]
-
-    def coerce(self, value):
-        try:
-            return int(value)
-        except:
-            try:
-                return int(float(value))
-            except:
-                return int(LONG_TYPE(value))
+    value = Trait(
+        "white",
+        {"white": 0, "red": 1, (0, 0, 0): 999},
+        str_cast_to_int,
+    )
 
 
-class FloatRangeTrait(HasTraits):
-    value = Trait(3.0, TraitRange(2.0, 5.0))
+class TestTraitWithMappingAndCallable(unittest.TestCase):
+    """ Test that demonstrates a usage of Trait where TraitMap is used but it
+    cannot be replaced with Map. The callable causes the key value to be
+    changed to match the mapped value.
 
+    e.g. this would not work:
 
-class FloatRangeTest(AnyTraitTest):
+        value = Union(
+            Map({"white": 0, "red": 1, (0,0,0): 999}),
+            NewTraitType(),
+            default_value="white",
+        )
 
-    obj = FloatRangeTrait()
+        where NewTraitType is a subclass of TraitType with ``validate`` simply
+        calls str_cast_to_int
+    """
 
-    _default_value = 3.0
-    _good_values = [2.0, 3.0, 4.0, 5.0, 2.001, 4.999]
-    _bad_values = [
-        0,
-        1,
-        6,
-        LONG_TYPE(0),
-        LONG_TYPE(1),
-        LONG_TYPE(6),
-        1.999,
-        6.01,
-        "two",
-        "0.999",
-        "6.01",
-        None,
-    ]
+    def test_trait_default(self):
+        obj = TraitWithMappingAndCallable()
 
-    def coerce(self, value):
-        try:
-            return float(value)
-        except:
-            return float(LONG_TYPE(value))
+        # the value is not 'white' any more.
+        self.assertEqual(obj.value, 5)
+        self.assertEqual(obj.value_, 5)
+
+    def test_trait_set_value_use_callable(self):
+        obj = TraitWithMappingAndCallable(value="red")
+
+        # The value is not 'red' any more.
+        # the callable is used, not the mapping.
+        self.assertEqual(obj.value, 3)
+        self.assertEqual(obj.value_, 3)
+
+    def test_trait_set_value_use_mapping(self):
+        obj = TraitWithMappingAndCallable(value=(0, 0, 0))
+
+        # Now this uses the mapping, and the value is the original one.
+        self.assertEqual(obj.value, (0, 0, 0))
+        self.assertEqual(obj.value_, 999)
 
 
 # Old style class version:
@@ -801,7 +637,8 @@ class OldInstanceTrait(HasTraits):
 
 
 class OldInstanceTest(AnyTraitTest):
-    obj = OldInstanceTrait()
+    def setUp(self):
+        self.obj = OldInstanceTrait()
 
     _default_value = otrait_test1
     _good_values = [
@@ -813,14 +650,13 @@ class OldInstanceTest(AnyTraitTest):
     ]
     _bad_values = [
         0,
-        LONG_TYPE(0),
         0.0,
         0j,
         OTraitTest1,
         OTraitTest2,
         OBadTraitTest(),
+        b"bytes",
         "string",
-        u"string",
         [otrait_test1],
         (otrait_test1,),
         {"data": otrait_test1},
@@ -852,7 +688,8 @@ class NewInstanceTrait(HasTraits):
 
 
 class NewInstanceTest(AnyTraitTest):
-    obj = NewInstanceTrait()
+    def setUp(self):
+        self.obj = NewInstanceTrait()
 
     _default_value = ntrait_test1
     _good_values = [
@@ -864,14 +701,13 @@ class NewInstanceTest(AnyTraitTest):
     ]
     _bad_values = [
         0,
-        LONG_TYPE(0),
         0.0,
         0j,
         NTraitTest1,
         NTraitTest2,
         NBadTraitTest(),
+        b"bytes",
         "string",
-        u"string",
         [ntrait_test1],
         (ntrait_test1,),
         {"data": ntrait_test1},
@@ -942,7 +778,8 @@ class OddIntegerTrait(HasTraits):
 
 
 class OddIntegerTest(AnyTraitTest):
-    obj = OddIntegerTrait()
+    def setUp(self):
+        self.obj = OddIntegerTrait()
 
     _default_value = 99
     _good_values = [
@@ -952,12 +789,6 @@ class OddIntegerTest(AnyTraitTest):
         7,
         9,
         999999999,
-        LONG_TYPE(1),
-        LONG_TYPE(3),
-        LONG_TYPE(5),
-        LONG_TYPE(7),
-        LONG_TYPE(9),
-        LONG_TYPE(999999999),
         1.0,
         3.0,
         5.0,
@@ -970,12 +801,6 @@ class OddIntegerTest(AnyTraitTest):
         -7,
         -9,
         -999999999,
-        LONG_TYPE(-1),
-        LONG_TYPE(-3),
-        LONG_TYPE(-5),
-        LONG_TYPE(-7),
-        LONG_TYPE(-9),
-        LONG_TYPE(-999999999),
         -1.0,
         -3.0,
         -5.0,
@@ -1006,13 +831,8 @@ class NotifierTraits(HasTraits):
 
 
 class NotifierTests(unittest.TestCase):
-    obj = NotifierTraits()
-
-    def __init__(self, value):
-        unittest.TestCase.__init__(self, value)
-
     def setUp(self):
-        obj = self.obj
+        obj = self.obj = NotifierTraits()
         obj.value1 = 0
         obj.value2 = 0
         obj.value1_count = 0
@@ -1178,31 +998,38 @@ class DelegateTests(unittest.TestCase):
 
 # Make a TraitCompound handler that does not have a fast_validate so we can
 # check for a particular regression.
-slow = Trait(1, TraitRange(1, 3), TraitRange(-3, -1))
+slow = Trait(1, Range(1, 3), Range(-3, -1))
 try:
     del slow.handler.fast_validate
 except AttributeError:
     pass
 
 
-class complex_value(HasTraits):
-    num1 = Trait(1, TraitRange(1, 5), TraitRange(-5, -1))
-    num2 = Trait(
-        1,
-        TraitRange(1, 5),
-        TraitPrefixList("one", "two", "three", "four", "five"),
-    )
-    num3 = Trait(
-        1,
-        TraitRange(1, 5),
-        TraitPrefixMap({"one": 1, "two": 2, "three": 3, "four": 4, "five": 5}),
-    )
-    num4 = Trait(1, Trait(1, Tuple, slow), 10)
-    num5 = Trait(1, 10, Trait(1, Tuple, slow))
+# Suppress DeprecationWarnings from TraitPrefixList and TraitPrefixMap
+with warnings.catch_warnings():
+    warnings.filterwarnings(action="ignore", category=DeprecationWarning)
+
+    class complex_value(HasTraits):
+        num1 = Trait(1, Range(1, 5), Range(-5, -1))
+        num2 = Trait(
+            1,
+            Range(1, 5),
+            TraitPrefixList("one", "two", "three", "four", "five"),
+        )
+        num3 = Trait(
+            1,
+            Range(1, 5),
+            TraitPrefixMap(
+                {"one": 1, "two": 2, "three": 3, "four": 4, "five": 5}
+            ),
+        )
+        num4 = Trait(1, Trait(1, Tuple, slow), 10)
+        num5 = Trait(1, 10, Trait(1, Tuple, slow))
 
 
 class test_complex_value(test_base2):
-    obj = complex_value()
+    def setUp(self):
+        self.obj = complex_value()
 
     def test_num1(self):
         self.check_values(
@@ -1239,19 +1066,19 @@ class test_complex_value(test_base2):
         )
 
 
-class list_value(HasTraits):
-    # Trait definitions:
-    list1 = Trait([2], TraitList(Trait([1, 2, 3, 4]), maxlen=4))
-    list2 = Trait([2], TraitList(Trait([1, 2, 3, 4]), minlen=1, maxlen=4))
-    alist = List()
-
-
 class test_list_value(test_base2):
-
-    obj = list_value()
-
     def setUp(self):
-        test_base2.setUp(self)
+        with self.assertWarns(DeprecationWarning):
+
+            class list_value(HasTraits):
+                # Trait definitions:
+                list1 = Trait([2], TraitList(Trait([1, 2, 3, 4]), maxlen=4))
+                list2 = Trait(
+                    [2], TraitList(Trait([1, 2, 3, 4]), minlen=1, maxlen=4)
+                )
+                alist = List()
+
+        self.obj = list_value()
         self.last_event = None
 
     def tearDown(self):
@@ -1316,18 +1143,6 @@ class test_list_value(test_base2):
     def test_trait_list_event(self):
         """ Record TraitListEvent behavior.
         """
-        # FIXME: The behavior of TraitListEvent is suboptimal with
-        # respect to extended slice changes. Previously, TraitListObject
-        # used to have a __setitem__() and a separate __setslice__() to
-        # handle non-extended slices. Extended slices were added to the
-        # underlying list object later. The __setitem__() code handled
-        # the new extended slices, but created the TraitListEvent in the
-        # same way it did for an integer index; namely it wrapped the
-        # value with a list. For simple slices, the `index` attribute of
-        # the TraitListEvent is an integer, and the `added` list is just
-        # the list of values added. For an extended slice, the `index`
-        # attribute is the slice object and the `added` list is the list
-        # of values wrapped in another list.
         self.obj.alist = [1, 2, 3, 4]
         self.obj.on_trait_change(self._record_trait_list_event, "alist_items")
         del self.obj.alist[0]
@@ -1340,16 +1155,19 @@ class test_list_value(test_base2):
         self.assertLastTraitListEventEqual(0, [6, 7], [4, 5])
         self.obj.alist[0:2:1] = [8, 9]
         self.assertLastTraitListEventEqual(0, [4, 5], [8, 9])
-        old_event = self.last_event
         self.obj.alist[0:2:1] = [8, 9]
-        # If no values changed, no new TraitListEvent will be generated.
+        # If list values stay the same, a new TraitListEvent will be generated.
+        self.assertLastTraitListEventEqual(0, [8, 9], [8, 9])
+        old_event = self.last_event
+        self.obj.alist[4:] = []
+        # If no structural change, NO new TraitListEvent will be generated.
         self.assertIs(self.last_event, old_event)
         self.obj.alist[0:4:2] = [10, 11]
         self.assertLastTraitListEventEqual(
-            slice(0, 4, 2), [[8, 4]], [[10, 11]]
+            slice(0, 3, 2), [8, 4], [10, 11]
         )
         del self.obj.alist[1:4:2]
-        self.assertLastTraitListEventEqual(slice(1, 4, 2), [[9, 5]], [])
+        self.assertLastTraitListEventEqual(slice(1, 4, 2), [9, 5], [])
         self.obj.alist = [1, 2, 3, 4]
         del self.obj.alist[2:4]
         self.assertLastTraitListEventEqual(2, [3, 4], [])
@@ -1394,3 +1212,152 @@ class TestThis(unittest.TestCase):
         with self.assertRaises(TraitError):
             d.allows_none = object()
         self.assertIsNone(d.allows_none)
+
+
+class ComparisonModeTests(unittest.TestCase):
+    def test_comparison_mode_none(self):
+        class HasComparisonMode(HasTraits):
+            bar = Trait(comparison_mode=ComparisonMode.none)
+
+        old_compare = HasComparisonMode()
+        events = []
+        old_compare.on_trait_change(lambda: events.append(None), "bar")
+
+        some_list = [1, 2, 3]
+
+        self.assertEqual(len(events), 0)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 2)
+        old_compare.bar = [1, 2, 3]
+        self.assertEqual(len(events), 3)
+        old_compare.bar = [4, 5, 6]
+        self.assertEqual(len(events), 4)
+
+    def test_comparison_mode_identity(self):
+        class HasComparisonMode(HasTraits):
+            bar = Trait(comparison_mode=ComparisonMode.identity)
+
+        old_compare = HasComparisonMode()
+        events = []
+        old_compare.on_trait_change(lambda: events.append(None), "bar")
+
+        some_list = [1, 2, 3]
+
+        self.assertEqual(len(events), 0)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = [1, 2, 3]
+        self.assertEqual(len(events), 2)
+        old_compare.bar = [4, 5, 6]
+        self.assertEqual(len(events), 3)
+
+    def test_comparison_mode_equality(self):
+        class HasComparisonMode(HasTraits):
+            bar = Trait(comparison_mode=ComparisonMode.equality)
+
+        old_compare = HasComparisonMode()
+        events = []
+        old_compare.on_trait_change(lambda: events.append(None), "bar")
+
+        some_list = [1, 2, 3]
+
+        self.assertEqual(len(events), 0)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = [1, 2, 3]
+        self.assertEqual(len(events), 1)
+        old_compare.bar = [4, 5, 6]
+        self.assertEqual(len(events), 2)
+
+    def test_rich_compare_false(self):
+        with warnings.catch_warnings(record=True) as warn_msgs:
+            warnings.simplefilter("always", DeprecationWarning)
+
+            class OldRichCompare(HasTraits):
+                bar = Trait(rich_compare=False)
+
+        # Check for a DeprecationWarning.
+        self.assertEqual(len(warn_msgs), 1)
+        warn_msg = warn_msgs[0]
+        self.assertIs(warn_msg.category, DeprecationWarning)
+        self.assertIn(
+            "'rich_compare' metadata has been deprecated",
+            str(warn_msg.message)
+        )
+        _, _, this_module = __name__.rpartition(".")
+        self.assertIn(this_module, warn_msg.filename)
+
+        # Behaviour matches comparison_mode=ComparisonMode.identity.
+        old_compare = OldRichCompare()
+        events = []
+        old_compare.on_trait_change(lambda: events.append(None), "bar")
+
+        some_list = [1, 2, 3]
+
+        self.assertEqual(len(events), 0)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = [1, 2, 3]
+        self.assertEqual(len(events), 2)
+        old_compare.bar = [4, 5, 6]
+        self.assertEqual(len(events), 3)
+
+    def test_rich_compare_true(self):
+        with warnings.catch_warnings(record=True) as warn_msgs:
+            warnings.simplefilter("always", DeprecationWarning)
+
+            class OldRichCompare(HasTraits):
+                bar = Trait(rich_compare=True)
+
+        # Check for a DeprecationWarning.
+        self.assertEqual(len(warn_msgs), 1)
+        warn_msg = warn_msgs[0]
+        self.assertIs(warn_msg.category, DeprecationWarning)
+        self.assertIn(
+            "'rich_compare' metadata has been deprecated",
+            str(warn_msg.message)
+        )
+        _, _, this_module = __name__.rpartition(".")
+        self.assertIn(this_module, warn_msg.filename)
+
+        # Behaviour matches comparison_mode=ComparisonMode.identity.
+        old_compare = OldRichCompare()
+        events = []
+        old_compare.on_trait_change(lambda: events.append(None), "bar")
+
+        some_list = [1, 2, 3]
+
+        self.assertEqual(len(events), 0)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = some_list
+        self.assertEqual(len(events), 1)
+        old_compare.bar = [1, 2, 3]
+        self.assertEqual(len(events), 1)
+        old_compare.bar = [4, 5, 6]
+        self.assertEqual(len(events), 2)
+
+
+@requires_traitsui
+class TestDeprecatedTraits(unittest.TestCase):
+
+    def test_color_deprecated(self):
+        with self.assertWarnsRegex(DeprecationWarning, "'Color' in 'traits'"):
+            Color()
+
+    def test_rgb_color_deprecated(self):
+        with self.assertWarnsRegex(DeprecationWarning,
+                                   "'RGBColor' in 'traits'"):
+            RGBColor()
+
+    def test_font_deprecated(self):
+        with self.assertWarnsRegex(DeprecationWarning, "'Font' in 'traits'"):
+            Font()
