@@ -1,25 +1,22 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2013, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in /LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ Test cases for weakref (WeakRef) traits. """
 
 import contextlib
 import gc
+import unittest
 
-from traits.testing.unittest_tools import unittest, UnittestTools
-
-from ..trait_types import Str, WeakRef
-from ..has_traits import HasTraits
+from traits.has_traits import HasTraits
+from traits.trait_types import Str, WeakRef
+from traits.testing.unittest_tools import UnittestTools
 
 
 class Eggs(HasTraits):
@@ -47,7 +44,7 @@ class TestWeakRef(UnittestTools, unittest.TestCase):
     """ Test cases for weakref (WeakRef) traits. """
 
     def test_set_and_get(self):
-        eggs = Eggs(name='platypus')
+        eggs = Eggs(name="platypus")
         spam = Spam()
         self.assertIsNone(spam.eggs)
         spam.eggs = eggs
@@ -56,15 +53,15 @@ class TestWeakRef(UnittestTools, unittest.TestCase):
         self.assertIsNone(spam.eggs)
 
     def test_target_freed_notification(self):
-        eggs = Eggs(name='duck')
+        eggs = Eggs(name="duck")
         spam = Spam(eggs=eggs)
 
         # Removal of the last reference to 'eggs' should trigger notification.
-        with self.assertTraitChanges(spam, 'eggs'):
+        with self.assertTraitChanges(spam, "eggs"):
             del eggs
 
     def test_weakref_trait_doesnt_leak_cycles(self):
-        eggs = Eggs(name='ostrich')
+        eggs = Eggs(name="ostrich")
         with restore_gc_state():
             gc.disable()
             gc.collect()
