@@ -1,16 +1,13 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2013, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 """ Record trait change events in single and multi-threaded environments.
 
 """
@@ -20,24 +17,21 @@ import threading
 from contextlib import contextmanager
 from datetime import datetime
 
-import six
-
 from traits import trait_notifiers
 
 
 CHANGEMSG = (
-    u"{time} {direction:-{direction}{length}} {name!r} changed from "
+    "{time} {direction:-{direction}{length}} {name!r} changed from "
     "{old!r} to {new!r} in {class_name!r}\n"
 )
-CALLINGMSG = u"{time} {action:>{gap}}: {handler!r} in {source}\n"
+CALLINGMSG = "{time} {action:>{gap}}: {handler!r} in {source}\n"
 EXITMSG = (
-    u"{time} {direction:-{direction}{length}} "
+    "{time} {direction:-{direction}{length}} "
     "EXIT: {handler!r}{exception}\n"
 )
 SPACES_TO_ALIGN_WITH_CHANGE_MESSAGE = 9
 
 
-@six.python_2_unicode_compatible
 class SentinelRecord(object):
     """ Sentinel record to separate groups of chained change event dispatches.
 
@@ -46,10 +40,9 @@ class SentinelRecord(object):
     __slots__ = ()
 
     def __str__(self):
-        return u"\n"
+        return "\n"
 
 
-@six.python_2_unicode_compatible
 class ChangeMessageRecord(object):
     """ Message record for a change event dispatch.
 
@@ -84,7 +77,6 @@ class ChangeMessageRecord(object):
         )
 
 
-@six.python_2_unicode_compatible
 class CallingMessageRecord(object):
     """ Message record for a change handler call.
 
@@ -113,7 +105,6 @@ class CallingMessageRecord(object):
         )
 
 
-@six.python_2_unicode_compatible
 class ExitMessageRecord(object):
     """ Message record for returning from a change event dispatch.
 
@@ -163,9 +154,9 @@ class RecordContainer(object):
         """ Save the records into a file.
 
         """
-        with open(filename, "w") as fh:
+        with open(filename, "w", encoding="utf-8") as fh:
             for record in self._records:
-                fh.write(six.text_type(record))
+                fh.write(str(record))
 
 
 class MultiThreadRecordContainer(object):
@@ -205,7 +196,7 @@ class MultiThreadRecordContainer(object):
         """
         with self._creation_lock:
             containers = self._record_containers
-            for thread_name, container in six.iteritems(containers):
+            for thread_name, container in containers.items():
                 filename = os.path.join(
                     directory_name, "{0}.trace".format(thread_name)
                 )
@@ -215,17 +206,20 @@ class MultiThreadRecordContainer(object):
 class ChangeEventRecorder(object):
     """ A single thread trait change event recorder.
 
+    Parameters
+    ----------
+    container : MultiThreadRecordContainer
+        A container to store the records for each trait change.
+
+    Attributes
+    ----------
+    container : MultiThreadRecordContainer
+        A container to store the records for each trait change.
+    indent : int
+        Indentation level when reporting chained events.
     """
 
     def __init__(self, container):
-        """ Class constructor
-
-        Parameters
-        ----------
-        container : MultiThreadRecordContainer
-           An container to store the records for each trait change.
-
-        """
         self.indent = 1
         self.container = container
 
@@ -290,18 +284,22 @@ class MultiThreadChangeEventRecorder(object):
     The class manages multiple ChangeEventRecorders which record trait change
     events for each thread in a separate file.
 
+    Parameters
+    ----------
+    container : MultiThreadChangeEventRecorder
+        The container of RecordContainers to keep the trait change records
+        for each thread.
+
+    Attributes
+    ----------
+    container : MultiThreadChangeEventRecorder
+        The container of RecordContainers to keep the trait change records
+        for each thread.
+    tracers : dict
+        Mapping from threads to ChangeEventRecorder instances.
     """
 
     def __init__(self, container):
-        """ Object constructor
-
-        Parameters
-        ----------
-        container : MultiThreadChangeEventRecorder
-            The container of RecordContainers to keep the trait change records
-            for each thread.
-
-        """
         self.tracers = {}
         self._tracer_lock = threading.Lock()
         self.container = container
@@ -348,18 +346,17 @@ class MultiThreadChangeEventRecorder(object):
 def record_events():
     """ Multi-threaded trait change event tracer.
 
-    Usage
-    -----
-    ::
+    Example
+    -------
+
+    This will install a tracer that will record all events that occur from
+    setting of some_trait on the my_model instance::
 
         >>> from trace_recorder import record_events
         >>> with record_events() as change_event_container:
         ...     my_model.some_trait = True
         >>> change_event_container.save_to_directory('C:\\dev\\trace')
 
-    This will install a tracer that will record all events that occur from
-    setting of some_trait on the my_model instance.
-
     The results will be stored in one file per running thread in the
     directory 'C:\\dev\\trace'.  The files are named after the thread being
     traced.
