@@ -1,18 +1,16 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2005, 2006 by Enthought, Inc.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought util package component>
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
+
 import os
 
+
 def get_home_directory():
     """ Determine the user's home directory."""
 
@@ -23,8 +21,8 @@ def get_home_directory():
     #       path = os.path.expanduser('~')
     # The above seems to work on both Windows and Unixes though the docs
     # indicate it might not work as well on Macs.
-    for name in ['HOME', 'USERPROFILE']:
-        if os.environ.has_key(name):
+    for name in ["HOME", "USERPROFILE"]:
+        if name in os.environ:
             # Make sure that the path ends with a path separator.
             path = os.environ[name]
             if path[-1] != os.path.sep:
@@ -34,6 +32,6 @@ def get_home_directory():
 
     # If all else fails, the current directory will do.
     else:
-        path = ''
+        path = ""
 
     return path
